==> karmajs-bootstrap-0.1.2.tgz: package/lib/index.js <==
require('coffee-script/register');

var server = require('../node_modules/karma/lib/server');
var _ = require('../node_modules/lodash/lodash.js');

var mergeConfig = {
  //configFile: '/Users/roberto/Desktop/karmajs-bootstrap/karma.conf.coffee'
  action: 'start'
  ,browsers: ['Firefox']
  ,frameworks: ['mocha', 'requirejs']
  ,files: [
    {pattern: 'components/jquery/dist/jquery.min.js', included: false, served: true},
    {pattern: 'components/lodash/dist/lodash.min.js', included: false, served: true},
    {pattern: 'components/requirejs-text/text.js', included: false, served: true},
    {pattern: 'components/chai/chai.js', included: false, served: true},
    'test/karma-bootstrap.coffee',
    {pattern: 'test/**/*.coffee', included: false},
    {pattern: 'test/**/*.yml', included: true, served: true}
  ]
  ,client: {
    args: [],
    useIframe: true,
    captureConsole: true
  }
  ,yamlPreprocessor:{
    options:{
      sourceMap: true
    }
  }
  ,coffeePreprocessor:{
    options:{
      sourceMap: true
    }
  }
  ,preprocessors: {
    'test/**/*.coffee': 'coffee',
    'test/uilits/api/json/partial/productTemplate.yml': 'yaml'
  }
  ,coverageReporter: {
    type : 'html',
    dir : 'coverage/'
  }
};

var defaultConfig = {
  basePath: './'
  ,exclude: []
  ,colors: true
  ,autoWatch: true
  ,autoWatchBatchDelay: 250
  ,reporters: ['dots', 'coverage']
  ,singleRun: true
  ,captureTimeout: 60000
  ,proxies: {}
  ,proxyValidateSSL: true
  ,preprocessors: {}
  ,urlRoot: '/'
  ,reportSlowerThan: 0
  ,transports: ['websocket', 'flashsocket', 'xhr-polling', 'jsonp-polling']
  ,plugins: ['karma-*']
  ,browserDisconnectTimeout: 2000
  ,browserDisconnectTolerance: 2
  ,browserNoActivityTimeout: 10000
};

var handleFileMerge = function(configObj, settingObj) {
  if(_.isArray(configObj)){
    return settingObj.concat(configObj);
  }else{
    return settingObj;
  }
}

var handleConfigType = function(result, value, key) {
  if(_.has(result, key)){
    switch(key){
      case 'files':
        result[key] = handleFileMerge(result[key], value);
        return result;
        break;
      default:
        result[key] = value;
        return result;
        break;
    }
  }else{
    result[key] = value;
    return result;
  }
}

var defaultsDeep = function(config, setting) {
  var mapper = _.reduce(setting, function(result, value, key) {
    return handleConfigType(result, value, key);
  }, config);
  console.log(mapper);
  return mapper;
};

exports = module.exports = {
  start: function(userConfig){
    var config = defaultsDeep(_.assign(defaultConfig, userConfig), mergeConfig);
    server.start(config);
  }
}

==> karmajs-bootstrap-0.2.1.tgz: package/lib/index.js <==
require('coffee-script/register');

var server = require('../node_modules/karma/lib/server');
var _ = require('../node_modules/lodash/lodash.js');
var path= require('path');

var basePattern = path.resolve(__dirname + '/../');

var preprocessors = {};
preprocessors[basePattern + '/test/**/*.coffee'] = 'coffee'

var mergeConfig = {
  //configFile: '/Users/roberto/Desktop/karmajs-bootstrap/karma.conf.coffee'
  action: 'start'
  ,browsers: ['Firefox']
  ,frameworks: ['mocha', 'requirejs']
  ,files: [
    {pattern: basePattern + '/components/jquery/dist/jquery.min.js', included: false, served: true},
    {pattern: basePattern + '/components/lodash/dist/lodash.min.js', included: false, served: true},
    {pattern: basePattern + '/components/requirejs-text/text.js', included: false, served: true},
    {pattern: basePattern + '/components/chai/chai.js', included: false, served: true},
    basePattern + '/test/karma-bootstrap.coffee',
    {pattern: basePattern + '/test/**/*.coffee', included: false}
  ]
  ,client: {
    args: [],
    useIframe: true,
    captureConsole: true
  }
  ,yamlPreprocessor:{
    options:{
      sourceMap: true
    }
  }
  ,coffeePreprocessor:{
    options:{
      sourceMap: true
    }
  }
  ,preprocessors: {
    'test/**/*.coffee': 'coffee'
  }
  ,coverageReporter: {}
};

var defaultConfig = {
  basePath: './'
  ,exclude: []
  ,colors: true
  ,autoWatch: true
  ,autoWatchBatchDelay: 250
  ,reporters: ['dots', 'coverage']
  ,singleRun: true
  ,captureTimeout: 60000
  ,proxies: {}
  ,proxyValidateSSL: true
  ,preprocessors: {}
  ,urlRoot: '/'
  ,reportSlowerThan: 0
  ,transports: ['websocket', 'flashsocket', 'xhr-polling', 'jsonp-polling']
  ,plugins: ['karma-*']
  ,browserDisconnectTimeout: 2000
  ,browserDisconnectTolerance: 2
  ,browserNoActivityTimeout: 10000
};

var handleFileMerge = function(configObj, settingObj) {
  if(_.isArray(configObj)){
    return settingObj.concat(configObj);
  }else{
    return settingObj;
  }
}

var handleObjectMerge = function(configObj, settingObj) {
  if(_.isPlainObject(configObj)){
    return _.merge(configObj, settingObj);
  }else{
    return settingObj;
  }
}

var handleConfigType = function(result, value, key) {
  if(_.has(result, key)){
    switch(key){
      case 'preprocessors':
        result[key] = handleObjectMerge(result[key], value);
        return result;
        break;

      case 'coverageReporter':
        result[key] = handleObjectMerge(result[key], value);
        return result;
        break;

      case 'client':
        result[key] = handleObjectMerge(result[key], value);
        return result;
        break;

      case 'coffeePreprocessor':
        result[key] = handleObjectMerge(result[key], value);
        return result;
        break;

      case 'yamlPreprocessor':
        result[key] = handleObjectMerge(result[key], value);
        return result;
        break;

      case 'files':
        result[key] = handleFileMerge(result[key], value);
        return result;
        break;
      default:
        result[key] = value;
        return result;
        break;
    }
  }else{
    result[key] = value;
    return result;
  }
}

var defaultsDeep = function(config, setting) {
  var mapper = _.reduce(setting, function(result, value, key) {
    return handleConfigType(result, value, key);
  }, config);
  console.log(mapper);
  return mapper;
};

exports = module.exports = {
  start: function(userConfig){
    var config = defaultsDeep(_.assign(defaultConfig, userConfig), mergeConfig);
    server.start(config);
  }
}
